@@ -16,6 +16,11 @@ def _jupyter_nbextension_paths():
             src="sparql_syntax/static",
             dest="sparql_syntax",
             require="sparql_syntax/main"),
+        dict(
+            section="notebook",
+            src="opencypher_syntax/static",
+            dest="opencypher_syntax",
+            require="opencypher_syntax/main"),
         dict(
             section="notebook",
             src="neptune_menu/static",
